@@ -9,13 +9,13 @@
 #import "MyItem.h"
 
 @interface DataFile : MyItem {
-  unsigned size;
+  unsigned long long size;
 	NSString *filename;
 //	NSDate *timestamp;
 	NSString *fullPath;
 }
-- (void)setSize:(unsigned)newSize;
-- (unsigned int)size;
+- (void)setSize:(unsigned long long)newSize;
+- (unsigned long long)size;
 - (void)setFilename:(NSString *)newFilename;
 - (NSString *)filename;
 //- (void)setTimestamp:(NSDate *)newTimestamp;
