@@ -33,10 +33,17 @@
 }
 
 - (id)initWithBrowser:(NSBrowser *)newBrowser atLocation:(NSString *)newLocation
+{
+	return [self initWithBrowser:newBrowser atLocation:@"/" withAllowedExtensions:nil];
+}
+
+- (id)initWithBrowser:(NSBrowser *)newBrowser atLocation:(NSString *)newLocation withAllowedExtensions:(NSArray *)newAllowedExtensions
 {
 	if (self = [super init])
 	{
 		[self setBrowser:newBrowser];
+		allowedExtensions = newAllowedExtensions;
+		[allowedExtensions retain];
 		[self setBaseLocation:newLocation];
 	}
 	return self;
@@ -107,14 +114,57 @@
  */
 - (void)setBaseLocation:(NSString *)newBaseLocation
 {
+	//NSLog(@"NSBrowser setBaseLocation");
+	
 	if (newBaseLocation == nil)
 		newBaseLocation = @"";
-	// get immutable copy
-	newBaseLocation = [NSString stringWithString:newBaseLocation];
+	// get immutable copy and expand the ~ in path if there is one
+	newBaseLocation = [newBaseLocation stringByExpandingTildeInPath];
 	[newBaseLocation retain];
 	[baseLocation release];
 	baseLocation = newBaseLocation;
-	[browser setPath:baseLocation];
+
+	// here we select the rows manually
+	// this is because doing a NSBrowser setPath causes
+	// *all* lower nodes to be loaded, and this can take a long
+	// time for large directories.
+	
+	// start at the bottom
+	[browser setPath:@"/"];
+	
+	// done if we don't have anything to select
+	if ([newBaseLocation length] == 0)
+		return;
+	
+	NSArray *pathComponents = [newBaseLocation pathComponents];
+	NSEnumerator* enumerator = [pathComponents objectEnumerator];
+	NSString *component = [enumerator nextObject];
+	
+	// give up if we don't have an absolute path
+	if (![component isEqualToString:@"/"])
+	{
+		return;
+	}
+	
+	// go through each level one by one, selecting where we should be
+	// although this goes through the whole directory structure, just as it does when
+	// we setPath, this avoids overhead of creating the cells and icons so is much
+	// faster.
+	FileSystemBrowserNode *parentNode = [FileSystemBrowserNode nodeWithParent:nil atRelativePath:@"/"];
+	int column = 0;
+	while (component = [enumerator nextObject])
+	{
+		int index = [parentNode rowIndexForNode:component];
+		if (index == -1)
+			break;
+		
+		[browser selectRow:index inColumn:column];
+		
+		parentNode = [FileSystemBrowserNode nodeWithParent:parentNode atRelativePath:component];
+	
+		column++;
+	}
+	//[browser setPath:baseLocation];
 	// no need to reload data as setPath: will
 }
 
@@ -171,7 +221,7 @@
 }
 
 // delegate methods
-- (int)browser:(NSBrowser *)sender numberOfRowsInColumn:(int)column {
+- (int)browser:(NSBrowser *)sender numberOfRowsInColumn:(int)column {	
 	NSString *path = nil;
 	FileSystemBrowserNode *node = nil;
 	
@@ -199,6 +249,8 @@
 	directoryContents = [containingDirNode visibleSubNodes];
 	displayedCellNode = [directoryContents objectAtIndex:row];
 	
+	//NSLog(@"displaying item %@, column %d, row %d", [displayedCellNode absolutePath], column, row);
+		
 	// See if this file has an allowed extension but allow all directories
 	if (![displayedCellNode isDirectory])
 	{
