@@ -509,7 +509,6 @@ StatusDisplayer *statusDisplayerGlobal;
 	else
 	{		
 		NSDate *date = [NSDate date];
-		
 		PTPObjectInfo oi;
 		unsigned short *unicodevalue = NULL;
 		uint16_t *uint16value = NULL;
@@ -1103,7 +1102,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		else if ([extension isEqualToString:@"qt"])
 			objectFormat = PTP_OFC_QT;
 		else if ([extension isEqualToString:@"jpg"] || [extension isEqualToString:@"jpeg"])
-			objectFormat = PTP_OFC_JFIF; // or should this be PTP_OFC_EXIF_JPEG?
+			objectFormat = PTP_OFC_EXIF_JPEG;
 		else if ([extension isEqualToString:@"tif"] || [extension isEqualToString:@"tiff"])
 			objectFormat = PTP_OFC_TIFF;
 		else if ([extension isEqualToString:@"bmp"])
