@@ -10,6 +10,7 @@
  */
 
 #import "NJBQueueItem.h"
+#import "NJBTransactionResult.h"
 
 @implementation NJBQueueItem
 
@@ -41,6 +42,8 @@
 		[self setDisplayStatus:YES];
 		[self setStatus:STATUS_UNKNOWN];
 		cancelled = NO;
+		
+		itemsToCancelIfFail = [[NSMutableArray alloc] init];
 	}
 	return self;
 }
@@ -51,6 +54,7 @@
 	[target release];
 	[object1 release];
 	[object2 release];
+	[itemsToCancelIfFail release];
 	[super dealloc];
 }
 
@@ -92,7 +96,7 @@
 	return status;
 }
 
-- (void)setRunInMainThread:(bool)newRunInMainThread
+- (void)setRunInMainThread:(BOOL)newRunInMainThread
 {
 	runInMainThread = newRunInMainThread;
 }
@@ -121,7 +125,7 @@
 {
 	if ([self cancelled])
 		return nil;
-	
+
 	id ret;
 	if (object1 == nil)
 		ret = [target performSelector:selector];
@@ -137,6 +141,18 @@
 	[object2 release];
 	object2 = nil;
 	
+	// this will crash if ret is not a class object, is there any way I can test this?
+	if ([itemsToCancelIfFail count] > 0 && [ret isKindOfClass:[NJBTransactionResult class]] && ![ret success])
+	{
+		NSEnumerator *enumerator = [itemsToCancelIfFail objectEnumerator];
+		NJBQueueItem *item;
+		while (item = [enumerator nextObject])
+			[item cancel];
+	}
+	// release all items now
+	[itemsToCancelIfFail release];
+	itemsToCancelIfFail = nil;
+	
 	return ret;
 }
 
@@ -149,6 +165,8 @@
 	object1 = nil;
 	[object2 release];
 	object2 = nil;
+	[itemsToCancelIfFail release];
+	itemsToCancelIfFail = nil;
 }
 
 - (BOOL)cancelled
@@ -156,4 +174,24 @@
 	return cancelled;
 }
 
+- (void)cancelItemIfFail:(NJBQueueItem *)item
+{
+	[itemsToCancelIfFail addObject:item];
+}
+
+/* retain the objects and target we have. This solves a complicated problem:
+ * If I create this object in one thread, by adding autoreleased objects, they get retain counts of 2
+ * then I add this object to the queue of the other thread, retaining me but not my objects (without this function)
+ * then I am released in the original thread, reducing the retain count of my objects to 1 which are then autoreleased
+ * which kills them.  So this is required.  Safe because I will be released and retained the same number of times (if I am
+ * to be freed).  Same for the objects.																																																								 
+ */
+- (id)retain
+{
+	[object1 retain];
+	[object2 retain];
+	[target retain];
+	return [super retain];
+}
+
 @end
