@@ -74,10 +74,9 @@
 }
 
 /* Returns the array of tracks.
- * If this is modified, the state will not
- * be updated. Should modify using addTrack/deleteTrack
+ * a bit nasty as this can be freed and be modified through here without updating our status...
  */
-- (NSMutableArray *)tracks
+- (NSArray *)tracks
 {
 	return tracks;
 }
