@@ -20,6 +20,16 @@
 	IBOutlet NSButton *changeMusicTabDir;
 	IBOutlet NSButton *changeDataTabDir;
 	IBOutlet NSButton *writeTagAfterCopy;
+	IBOutlet NSTextField *duplicatesLengthTol;
+	IBOutlet NSTextField *duplicatesFilesizeTol;
+	IBOutlet NSTextField *duplicatesTitleTol;
+	IBOutlet NSTextField *duplicatesArtistTol;
+	IBOutlet NSStepper *duplicatesLengthTolStepper;
+	IBOutlet NSStepper *duplicatesFilesizeTolStepper;
+	IBOutlet NSStepper *duplicatesTitleTolStepper;
+	IBOutlet NSStepper *duplicatesArtistTolStepper;
+	IBOutlet NSButton *enableTurbo;
+	
 	Preferences *preferences;
 	NSTabView *tabView;
 	BOOL isDirty;
@@ -40,4 +50,6 @@
 - (IBAction)musicTabDirLastUsed:(id)sender;
 - (IBAction)dataTabDirLastUsed:(id)sender;
 - (IBAction)writeTagAfterCopy:(id)sender;
+- (IBAction)enableTurbo:(id)sender;
+
 @end
