@@ -23,10 +23,11 @@ Boston, MA 02111-1307, USA.
 */
 
 #include <sys/stat.h>
-#include "util.h"
+//#include "util.h"
 #include "mp3file.h"
 #include <string.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include "glibdefs.h"
 
 /*
