@@ -96,6 +96,24 @@ static short ptp_write_func (unsigned char *bytes, unsigned int size, void *data
 	int result;
 	PTP_USB *ptp_usb=(PTP_USB *)data;
 	
+	
+	/* only print if size < something */
+	/*int i = 0;
+	 if (size < 0xff)
+	 {
+		 printf("-------------------------\n");
+		 printf("Sending data size %d\n", size);
+		 for (i = 0; i < size; i += 8)
+		 {
+			 int j = i;
+			 for (; j<size && j<i+8; j++)
+				 printf("0x%02x ", bytes[j]);
+			 printf("\n");
+		 }
+		 printf("-------------------------\n");
+	 }
+	 */
+	
 	result=USB_BULK_WRITE(ptp_usb->handle,ptp_usb->outep,(char *)bytes,size,ptpcam_usb_timeout);
 	if (result >= 0)
 		return (PTP_RC_OK);
